.. Pysprint documentation master file



.. _pysprint GitHub repository:   https://github.com/Ptrskay3/PySprint

Pysprint: Spectrally resolved interferometry in Python
======================================================

Pysprint provides a high-level interface for evaluating measurements
relying on spectrally resolved interferometry.

The Pysprint package is free software, using an Open Source MIT license. The
software and this document are works in progress. See the project at
`pysprint GitHub repository`_. The guide is in Hungarian for the time being,
english documentation is in progress.

Take the tour!
==============
.. toctree::
   :maxdepth: 2

   hu_intro.ipynb
   hu_dataset.ipynb
   hu_spp.ipynb
   hu_phase.ipynb
   hu_fft.ipynb
   hu_wft.ipynb
   hu_minmax.ipynb

API
===

.. toctree::
   :maxdepth: 2
   :caption: Read the API documentation:

   pysprint.core.methods

   pysprint.core.bases

   pysprint.utils



References
==========
.. toctree::
   :maxdepth: 2

   REFERENCES.md

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
